% SE 2021 hacky single reflectors
% The reflection coeffs of the according alighned
% shoebox wall are used if no material is specified for the reflector
%
% Rindel HP missing as well as diffraction if the specular reflection is
% not visible

function [isd] = create_reflector_data(ism_setup, room, op);

isd = [];

if ~isfield(room, 'reflectors')
    % early out
    return;
end

if ism_setup.src_outside || ism_setup.rec_outside
    % early out, SE 16.03., src and rec have to be in the same room as reflector
    return;
end

% test initialize one
%room.reflectors(1).reflection = [0 0 0]; 



numR = size(room.reflectors,2);
kk = 0;
for k = 1:numR
    % construct triangles
    refl = room.reflectors(k);
    
    
%     refl.origin = [8 60 1]
%     refl.normal = [0 -1 0]
%     refl.edgeLength = [5 0 2]
%     
%     refl.origin = [8 61 0.75]
%     refl.normal = [0 0 -1]
%     refl.edgeLength = [5 5 0]
%     
%      refl.origin = [8 61 0.75]
%     refl.normal = [1 0 0]
%     refl.edgeLength = [0 5 5]
    
    if sum(abs(refl.normal)==1) ~= 1
        warning('ignoring invalid reflector plane, normal not axis alighned');
        continue;
    end
    
    if refl.normal*refl.edgeLength'
        warning('ignoring invalid reflector plane, normal and edgeLenght not perpendicular');
        continue;
    end
    
    
    % get triangles
    [verts, mesh] = getTriangles(refl.origin, refl.normal, refl.edgeLength);
   
    % get plane
    plane = getPlane(verts, mesh);
    
    % reflect on plane, empty for back sides
    point = reflectPointOnPlane( room.srcpos, plane );
    
    if isempty(point)
       continue; 
    end
    
%     % strict visibility check using triangle intersection, however we
%     need smooth belnding in the diffraction area around the edges
%     % visible?
%     visible = 0;
%     for idx = 1:2
%         [intersect, t, u, v] = intersectRayTriangle(room.recpos, point-room.recpos, verts(mesh(idx,1),:), verts(mesh(idx,2),:), verts(mesh(idx,3),:), 4*eps);
%         
%         if intersect && t <= 1
%             visible = 1; % visible
%             break;
%         end
%     end
%  
%     if ~visible
%         continue;
%     end
    
    % get diffraction/reflection filter, this also tells us whether it is
    % visible
    [b,a] = limSizeDiffractionFilter( point, room.recpos, verts, plane, true, false, speedOfSound(room), op.fs );
    
    % visible? Including diffraction area
    if isempty(b)
        continue;
    end

    
    % valid and visble, continue
    kk = kk + 1; % this is how many we found

    %Remember this weird RAZR notation
    % The order of walls (directions of outside-pointing normal vectors) is:
    % {-z, -y, -x, +x, +y, +z}.

    % this stupidly expands the array
    isd.pattern(kk,:) = -refl.normal;  % in RAZR this points outside
    isd.invert_pos(kk,:) = abs(refl.normal);  % flip along this dimension, important for src directivity

    if isfield(room.reflectors(k),'material')
        %% reflection filter coefficients
        
        if op.ism_enableReflFilt
%             room.freq = [63 125 250         500        1000        2000        4000        8000]
%             room.reflectors(k).material= room.freq*0+0.99;
%             
%             room.freq = [500        1000        2000        4000        8000]
%             room.reflectors(k).material= room.freq*0+0.99;
%             
            [b_refl, a_refl] = getReflFiltCoeff(room.freq, room.reflectors(k).material, ...
                ism_setup.b_bp, ism_setup.a_bp, op);
        else
            b_refl = num2cell(ones(6, 1))';
            a_refl = ism_setup.b_refl;
        end
        isd.num_refl(kk,:) = [0 0 0 0 0 0];% do not use wall refl filters
     
        % use custom filer
        
        % add diffraction
        b_refl{3} = b;
        a_refl{3} = a;
        
     isd.b_custom{kk} = b_refl;
     isd.a_custom{kk} = a_refl;
     
       
        
    else
        if any(refl.normal>0)
            isd.num_refl(kk,:) = [fliplr(refl.normal) 0 0 0]; % use the respective reflection coeff {-z, -y, -x, +x, +y, +z}.
        else
            isd.num_refl(kk,:) = [0 0 0 -fliplr(refl.normal)];
        end  
        
     isd.b_custom{kk} = [];
     isd.a_custom{kk} = [];
    end

    isd.order(kk,1) = 1;
    isd.positions(kk,:) = point; % not used for spatialization
    isd.idx_auralize(kk,1) = true;
    isd.relpos(kk,:) = point - room.recpos;
    isd.b_diffr = [];
    isd.a_diffr = [];

%     isd.relpos(k,:) = [0 -2 0];
%     isd.azim(k) = 90;   % these are used for spatialization, where is the orientation of the image source?
%     isd.elev(k) = 0;   % these are used for spatialization
%     isd.lrscale(k,:) = [0 2];
%     isd.por(k) = 0.5000; % ?
%     isd.sor(k) = 258;  % paint here
%     isd.b_air(k,:) = 0.9674;
%     isd.a_air(k,:) = [1 -0.0326];
%     isd.filter_ranges(k,:) = [258 4668];
%     isd.sr = [];
  

end

% if we have no reflection, goodbye
if isempty(isd)
    return;
end

% now some code from scale_is_pattern

[isd.azim, isd.elev, distc] = ...
    cart2sph(isd.relpos(:, 1), isd.relpos(:, 2), isd.relpos(:, 3));  % az: -pi:pi, el: (-pi:pi)/2

%distc = distc + distce_add;
isd.azim = rd2dg(isd.azim);
isd.elev = rd2dg(isd.elev);

%%
%Account for source orientation 

% SE FIXME not tested for lim size reflector
if (op.ism_enableSourceDir)
    numSrc = size(isd.pattern, 1);
    %recpos = repmat(room.recpos, numSrc, 1);
    srcpos = isd.positions;
    
  
    % SE comment grab orientation of src in sperical coords (azimuth and
    % elevation of front direction is defined in room)
    srcaz_rad = dg2rd(room.srcdir(1));
    srcel_rad = dg2rd(room.srcdir(2));
    
    % SE comment convert to front pointing vector in world carthesian
    % coords
    [src_dirVec_x, src_dirVec_y, src_dirVec_z] = sph2cart(srcaz_rad,srcel_rad,1);
    src_dirVec = [src_dirVec_x, src_dirVec_y, src_dirVec_z];
    
    src_dirMat = repmat(src_dirVec,numSrc,1);
    
    invert_ind = (isd.invert_pos == 1);
    src_dirMat(invert_ind) = src_dirMat(invert_ind) * (-1); % SE these are the image src front vectors

  
    rel_srcpos = bsxfun (@minus, room.recpos, srcpos); % SE this is from src to rec
    
    useNew = 1;
    if (useNew)
    %%%%%%%%%%%%%%%%%%%%%%%%%
    % SE 19.04.2021 new code to derive the angle for the directivity filter
    rel_srcpos_len = sqrt(sum(rel_srcpos.^2,2));
    rel_dir = rel_srcpos./repmat(rel_srcpos_len,1,3);
    
    rel_dir_dot = sum(rel_dir.*src_dirMat,2); % dot product per IS
    
    % SE IMPORTANT we can only derive one angle, given that we have just a
    % front direction of the source and everything has to be symmetrical
    % around it. FIXME we have to change the angle definition to euler
    % angles pitch yaw roll or an a vector triplet (axis) front, left, up
    
    %%%%%%%%%%%%%% assuming no roll
    % we could make the implicit assumption that we never roll and can
    % construct front, left, up. Then we can project rel_dir_dot onto that
    % base and get azimuth and elev with cart2sph. BUT then we have to
    % convert again into just one angle at least for the old hs_filter src
    % directivity
    
    % construct left vector based on the assumption that we do not have
    % roll. This one rotates in the horizontal plane
    src_left = [-sin(srcaz_rad) cos(srcaz_rad) 0];
    % construc up vector orthogonal to the front and left
    src_up = cross( src_dirVec, src_left); % right-handed front, left, up
    
    src_leftMat = repmat(src_left,numSrc,1);
    src_leftMat(invert_ind) = src_leftMat(invert_ind) * (-1); % SE these are the image src front vectors
    src_upMat = repmat(src_up,numSrc,1);
    src_upMat(invert_ind) = src_upMat(invert_ind) * (-1); % SE these are the image src front vectors
    
    % now project srcrec direction onto the image's base
    rel_left_dot = sum(rel_dir.*src_leftMat,2);
    rel_up_dot = sum(rel_dir.*src_upMat,2);
    
    %rel_vecs = [rel_dir_dot rel_left_dot rel_up_dot];
    [azSE,elSE,~] = cart2sph(rel_dir_dot,rel_left_dot,rel_up_dot);
    isd.src_azim = 180*azSE/pi; % this is (-1)* Hennings old code 
    isd.src_elev = 180*elSE/pi; % this is the same as Hennings old code
    
    end
end


% % account for receiver orientation:
% isd.azim = isd.azim - room.recdir(1);
% isd.elev = isd.elev - room.recdir(2); 
% 
% [isd.azim, isd.elev] = wrap_angles([isd.azim, isd.elev], 'deg');

% % SE 11.10.2022 new correct rotations including elev
% anglesOut = transformAngles([azim elev],[room.recdir(1) room.recdir(2)],0,1); 
% CK 2023-02-17 is it this what he wants to do?
anglesOut = transformAngles([isd.src_azim  isd.src_elev],[room.recdir(1) room.recdir(2)],0,1); 

[isd.azim, isd.elev] = wrap_angles(anglesOut, 'deg');

isd.lrscale = panscale(room, isd.relpos);

%% attenuation and delay due to source-receiver distance

isd.por = distce_atten(distc, op.legacy_distce_atten);
isd.por(isd.order ~= 0) = isd.por(isd.order ~= 0) * 10^(op.ism_refl_gain/20);
isd.sor = max(round(distc/speedOfSound(room)*op.fs), 1);

% scaling factor for calibration:
isd.por = isd.por * 10^((op.SPL_source - op.SPL_at_0dBFS)/20);

%% air absorption filter coefficients

if op.ism_enableAirAbsFilt
    if op.ism_enableAirAbsFilt == -1
        dstnc = 10*distc.^(0.7);
    else
        dstnc = distc;
    end
    [isd.b_air, isd.a_air] = getAirAbsfiltCoeff(dstnc, op.fs, speedOfSound(room));
    
else
    isd.b_air = [];
    isd.a_air = [];
end
       


%%%%%%%%%%%%%%%%%%%%%%%%
% helper functions
%%%%%%%%%%%%%%%%%%%%%%%%
function [verts, mesh] = getTriangles(origin, normal, edgeLength)

idxN = find(normal ~= 0);
idx = find(normal == 0);

axis = [1 0 0; 0 1 0; 0 0 1];

verts = [ origin - axis(idx(1),:)*edgeLength(idx(1))/2 - axis(idx(2),:)*edgeLength(idx(2))/2; ...
    origin - axis(idx(1),:)*edgeLength(idx(1))/2 + axis(idx(2),:)*edgeLength(idx(2))/2; ...
    origin + axis(idx(1),:)*edgeLength(idx(1))/2 + axis(idx(2),:)*edgeLength(idx(2))/2; ...
    origin + axis(idx(1),:)*edgeLength(idx(1))/2 - axis(idx(2),:)*edgeLength(idx(2))/2];

if normal(idxN) < 0
    if idxN == 2
        mesh = [1 4 3; 3 2 1];
    else
        mesh = [1 2 3; 3 4 1];
    end
else
    if idxN == 2
        mesh = [1 2 3; 3 4 1];
    else
        mesh = [1 4 3; 3 2 1];
    end
end


function plane = getPlane(verts, mesh)
% use counter clock wise notation, like default GL_CCW, 

for idx = 1:size(mesh,1)
    tri = verts(mesh(idx, 1:3)',:);
    
    % convert tri into normal and distance to origin
    U = tri(2,:)-tri(1,:);
    V = tri(3,:)-tri(1,:);
    
    tri_normal = cross(U,V);   % CCW
    tri_normal = tri_normal/norm(tri_normal);
    tri_dist = (tri(1,:)*tri_normal'); % FIXED 19.06
end

plane.normal = tri_normal;
plane.dist = tri_dist;


function point = reflectPointOnPlane( point, plane )
        
% reflect only valid relections
if ( (plane.normal*plane.dist-point)*plane.normal' < 0 )
    d = -plane.dist + point*plane.normal';
    point = point - 2*d*plane.normal;
else
    % disp('reflection plane not reachable');
    point = [];
end


% eof
