function distsq = distancesq_on_unitsphere(azim1, elev1, azim2, elev2)
    % Returns squared distance on a unit shpere.
    % 
    % Usage:
    %  dist = distancesq_on_unitsphere(azim1, elev1, azim2, elev2)
    %
    % Input:
    %   azim1 : scalar or array
    %     Azimuth angle in degree of first point.
    %   elev1 : scalar or array
    %     Elevation angle in degree of first point.
    %   azim2 : scalar or array
    %     Azimuth angle in degree of second point.
    %   elev2 : scalar or array
    %     Elevation angle in degree of second point.
    %
    % Output:
    %   distsq : scalar or array
    %     Squared distance between (azim1, elev1) and (azim2, elev2)
    %     on the unit sphere (sphere with radius=1).
    %
    
%------------------------------------------------------------------------------
% RAZR engine for Mathwork's MATLAB
%
% Version 0.96.3
%
% Author(s): Siegfried Guendert
%
% Copyright (c) 2014-2023, Torben Wendt, Steven van de Par, Stephan Ewert,
% University of Oldenburg, Germany.
%
% This work is licensed under the
% Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International
% License (CC BY-NC-ND 4.0).
% To view a copy of this license, visit
% http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to
% Creative Commons, 444 Castro Street, Suite 900, Mountain View, California,
% 94041, USA.
%------------------------------------------------------------------------------

    distsq = ( ...
        2 - 2*cos(elev1/180*pi)*cos(elev2/180*pi).*cos((azim1-azim2)/180*pi) ...
        - 2*sin(elev1/180*pi)*sin(elev2/180*pi));  % SE formula, step in haversine derivation d^2/r^2
end

