function idx = find_nearest_coordinates_on_unitsphere(azim1, elev1, azim2, elev2, knearest)
    % Returns index of nearest cooordinates on unit sphere for given two coordinates
    %
    % Usage:
    %   idx = find_nearest_coordinates_on_unitsphere(azim1, elev1, azim2, elev2, knearest)
    %
    % Input:
    %   azim1 : scalar
    %     Azimuth angle in degree of first point.
    %   elev1 : scalar
    %     Elevation angle in degree of first point.
    %   azim2 : scalar or array
    %     Azimuth angle in degree of second point.
    %   elev2 : scalar or array
    %     Elevation angle in degree of second point.
    %   knearest : int
    %     Number of sorted nearest coordinates, nearest first.
    %     Default: knearest = 1.
    %
    % Returns:
    %   idx : int
    %     Index of nearest coordinates.
    
%------------------------------------------------------------------------------
% RAZR engine for Mathwork's MATLAB
%
% Version 0.96.3
%
% Author(s): Siegfried Guendert
%
% Copyright (c) 2014-2023, Torben Wendt, Steven van de Par, Stephan Ewert,
% University of Oldenburg, Germany.
%
% This work is licensed under the
% Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International
% License (CC BY-NC-ND 4.0).
% To view a copy of this license, visit
% http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to
% Creative Commons, 444 Castro Street, Suite 900, Mountain View, California,
% 94041, USA.
%------------------------------------------------------------------------------


    distancesq = distancesq_on_unitsphere(azim1, elev1, azim2, elev2);
    [~, idx] = sort(distancesq);
    if nargin < 5  % knearest was not provided by user
        idx = idx(1);
    else
        idx = idx(1:knearest);
    end
end
