function [idx, t, u, v] = find_triangle_on_hull(raydir, vertices, hull, geoeps)
    % Returns index of intersected triangle, intersection distance t and barycentric coordinates u,v
    %
    % Usage:
    %   [idx, t, u, v] = find_triangle_on_hull(raydir, vertices, hull, geoeps)

    % Input:
    %   raydir : vector (3)
    %     Ray direction vector (target).
    %   vertices : array Nx3
    %   hull : array Nx3
    %   geoeps : scalar
    %
    % Returns:
    %   idx : int
    %     Index of triangle, if intersected
    %
    
    for idx = 1:length(hull)
        tri_a = vertices(hull(idx, 1), :);
        tri_b = vertices(hull(idx, 2), :);
        tri_c = vertices(hull(idx, 3), :);
        [intersected, t, u, v] = intersect_ray_triangle(raydir, tri_a, tri_b, tri_c, geoeps);
        if intersected
            return
        end
    end

    % not returned inside for loop -> no intersected triangle found:
    idx = nan;
    t = nan;
    u = nan;
    v = nan;
end
