function[H] = smoothnew3se(H,oct,fs)
% Octave based smoothing.
% H = smoothnew3se(H,oct,[fs] )
%
% H is magnitude (positive frequency) input vector starting at f=0 (first bin) up to fs.  H out will be same (row/column)
% oct is smoothing constant in octaves
% fs is the sampling rate, if not provided,
% data is treated like if each bin == 1 Hz !! and the length(H) == fs
%    
% assume analytical signal for now
% H is real input vector.  H smoothed will be same.
%
%CHANGED 28/2/09 for working with 1Hz-Bin restriction
%CORRECTED 11/1/08 for window width (defined at -3 dB).  

% SE 12.09.2022 changes regarding window and interpolation points, needs
% further changes, 12.01.2023 changed to use optional fs, fixed erratic
% calculation of oct width, the whole function should be cleaned and moved
% out of external

if nargin == 2
    fs = length(H); % if we do not pass fs, we assume a 1s signal was transformed
end

% SE 12.01.2023 now using fs, calculate some real freqs
linF = (1:length(H)-1)/length(H)*fs;
stopf = (length(H)-1)/length(H)*fs; % highest f = linF(end)

% %if the frequency argument vector exist, there is no 1Hz-Bin-restriction
% if nargin == 4
%     df = f(2);
%     stopf = round(stopf/df)+1;%fstop is now the index not longer a Hz-value
% end

startf = fs/length(H);   % SE = linF(1) 

% SE 12.09.2022 increase resolution to make sure we have enough points at
% high f, actually doesnt matter much, can be anywhere from 0.5 to 4, more
% or less same result
N = 4*stopf;    %Number of samples for log warping.  This seems to work well.


% spacing = 10^(log10(stopf-startf)/N);   %this is a multiplicitive factor, not an even spacing
% Noct = oct*log10(2)/log10(spacing); %number of bins per xth octave

% SE points per requested octave fraction oct, the upper calculation is
% utter crap why the hell is there a difference?
Noct = oct/(log2(stopf/startf)/N); % requested oct fraction divided by oct/bin in logspace vector


%log warp
logF = logspace(log10(startf),log10(stopf),N);   
Hinterp = interp1(linF, H(2:end), logF, 'spline'); 

Noct_even = round(Noct/2)*2;    %so can divide by two later and use length(Noct_even) as argument to functions without uncertainty of rounding


%ADDED 11/1/08 to correct.  -3dB points of window should = Noct_even, not entire window.
% W = gausswin(Noct_even);
%W = gausswin(Noct_even*2);

% SE 12.09.2022 windows with correct equivalent rectangular bandwidth

W = gausswin(Noct_even*2,2.471749); % SE adjust alpha to meet equivalent rectangular bandwidth
%W = ones(Noct_even,1); % SE rectangular win
%W = hann(Noct_even*2); % SE raised cosine
%W = triang(Noct_even*2);  % SE triangular win

%extend the function to be smoothed to minimze errors at boundaries
lead = ones(1,length(W)).*Hinterp(1);
lag = ones(1,length(W)).*Hinterp(end);
Hinterp_extrap = [lead  Hinterp lag  ];

% figure(5)
% plot(H,'b')
% hold on
% plot(Hinterp,'g')
% plot(Hinterp_extrap,'r')
% hold off
% axis([0 20000 -60 0])


%convolve with smothing window
Htemp = fftfilt(W,Hinterp_extrap,length(W)*2)./sum(W);

Htemp = Htemp(length(lead)+.5*length(W)+1:length(lead)+.5*length(W)+length(Hinterp));   %get rid of extra bins from adding lead and lag
H(2:end) = interp1(logF, Htemp, linF, 'spline');   %back to linear domain





















