% source directivity filtering using SOFA files
% This script uses the entry point in `apply_source_dir(...)`
% since `apply_source_dir.m` only calls this as a script, it is not a function.
% So additionally the picking and filtering is done here.
% expected variables in the namespace (in scope of apply_source_dir):
% database, isd, ism_setup, n, signalmat, op
% dbase, cfg
%
% important used functions:
% - load_source_directivity_sofa()
% - pick_directional_ir()

%------------------------------------------------------------------------------
% RAZR engine for Mathwork's MATLAB
%
% Version 0.96.3
%
% Author(s): Siegfried Guendert
%
% Copyright (c) 2014-2023, Torben Wendt, Steven van de Par, Stephan Ewert,
% University of Oldenburg, Germany.
%
% This work is licensed under the
% Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International
% License (CC BY-NC-ND 4.0).
% To view a copy of this license, visit
% http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to
% Creative Commons, 444 Castro Street, Suite 900, Mountain View, California,
% 94041, USA.
%------------------------------------------------------------------------------


%% Paths and filenames    

if isfield(op, 'dir_database')
    sofa_filename = op.dir_database;  % override with direct specification
else
    sofa_filename = getfield(cfg, sprintf('dir_path__%s', dbase));
end
if isfile(sofa_filename)
    stDir = load_source_directivity_sofa( ...
        sofa_filename, true);
elseif isfield(op, 'dir_struct')
    stDir = op.dir_struct;
end

if stDir.fs ~= op.fs
    error('Source directivity SOFA file samplerate stDir.fs (%f) does not match op.fs (%f).', ...
        stDir.fs, op.fs);
end
    
src_azim = isd.src_azim(n);
src_elev = isd.src_elev(n);

ir = pick_directional_ir(src_azim, src_elev, stDir, op.dir_interpolation_method);

signalmat(:, n) = fftfilt(ir, signalmat(:, n)); % SE FIXME ir has samples in dimension 2, it works because fftfilt flips the dimensions
