clear
close all

%% Create semianechoic room   
room.name = 'Seminechoic';
room.boxsize = [11, 7, 9];
room.materials = zeros(6, 7);
room.materials(1, :) = 0.0;
room.materials(2:end, :) = 0.9999;    
room.freq = [125, 250 500 1e3 2e3 4e3, 8e3];
distance = 1;  % setting for direct sound, do not change
room.srcpos = [5+distance, 3.5, distance/2];
room.srcdir = [180, 0];
room.recpos = [room.srcpos(1)-distance, room.srcpos(2), room.srcpos(3)];
room.recdir	= [0, 0];
room.TCelsius = 20;
% scene(room)

%% Create options for the simulation
op = get_default_options();
op.spat_mode = 'diotic';  % omnidirectional receiver
op.ism_enableSourceDir = true;  % sourc with directivity filtering
op.dir_db = 'sofa';  
op.dir_interpolation_method = 'nearest';
op.return_rir_parts = true;  % we need the late IR part separately
op.fdn_enabled = false;
op.enableSR = false;
op.ism_order = 1;
op.ism_enableAirAbsFilt = false;
op.ism_enableDiffrFilt = false;
op.ism_enableToneCorr = false;
op.ism_enableReflFilt = true;
op.ism_enable_scattering = false;

%% Load Directivity Database
cfg = razr_cfg_user();
stDir = load_source_directivity_sofa(cfg.dir_path__sofa, true);
op.dir_struct = stDir;

%% Direct sound path test

ir_dir = razr(room, op);

distance_direct_m = norm(room.srcpos-room.recpos);
assert(abs(distance_direct_m-1)<1e-5, 'Direct path distance should be 1.')
distance_reflection_m = 2*sqrt((distance_direct_m/2)^2+room.srcpos(3)^2);

figure()
% index of direct sound impulse response
idx = knnsearch(stDir.vertices, [1,0,0]);
spec_srcdir = fft(stDir.IR(idx, :), [], 2);
spec_srcdir = spec_srcdir(1:end/2+1);
spec_srcdir(2:end-1) = 2 * spec_srcdir(2:end-1);
nfft = size(stDir.IR, 2);
freq_spec_srcdir = stDir.fs * (0:nfft/2) / nfft;

semilogx(freq_spec_srcdir, 20*log10(abs(spec_srcdir)));
hold on
spec_razr = fft(ir_dir.sig_direct(:,1), [], 1);
nfft = size(ir_dir.sig_direct, 1);
spec_razr = spec_razr(1:round(nfft/2+1));
spec_razr(2:end-1) = 2 * spec_razr(2:end-1);
freq_spec_razr = ir_dir.fs * (0:round(nfft/2)) / nfft;
semilogx(freq_spec_razr, 20*log10(abs(spec_razr)))
mx = max(20*log10(abs(spec_srcdir)));
ylim( [mx-20, mx+5])
xlim([50, 20e3])
grid on
xlabel('Frequency /Hz')
ylabel('|FRF| /dB(FS)')
title('Direct Path Source Directivity')
legend({'SOFA DIR', 'RAZR RIR'})
savefig('test_srcdir_semianechoic.direct.fig')
saveas(gcf(), 'test_srcdir_semianechoic.spectra.direct.png')

%% Reflection path (Azimuth 0° and elevation -45° path from source)
distance = 1/sqrt(2); % direct path distance
room.srcpos(1) = 5+distance;
room.srcpos(3) = distance/2;
room.recpos(1) = 5;
room.recpos(3) = distance/2;
% distance of reflection path shuld be equal 1 now
c_sound = speedOfSound(room);
% just test reflection path distance:
distance_direct_m = norm(room.srcpos-room.recpos);
distance_reflection_m = 2*sqrt((distance_direct_m/2)^2+room.srcpos(3)^2);
assert(abs(distance_reflection_m-1)<1e-5, 'Reflection path distance should be 1.')

ir_dir = razr(room, op);

% index of -45° impulse response
idx = knnsearch(stDir.vertices, [1/sqrt(2), 0, -1/sqrt(2)], 'K', 1);
spec_srcdir = fft(stDir.IR(idx, :), [], 2);
spec_srcdir = spec_srcdir(1:end/2+1);
spec_srcdir(2:end-1) = 2 * spec_srcdir(2:end-1);
nfft = size(stDir.IR, 2);
freq_spec_srcdir = stDir.fs * (0:nfft/2) / nfft;

figure()
semilogx(freq_spec_srcdir, 20*log10(abs(spec_srcdir)));
hold on
spec_razr = fft(ir_dir.sig_early(:,1), [], 1);
nfft = size(ir_dir.sig_direct, 1);
spec_razr = spec_razr(1:round(nfft/2+1));
spec_razr(2:end-1) = 2 * spec_razr(2:end-1);
freq_spec_razr = ir_dir.fs * (0:round(nfft/2)) / nfft;
semilogx(freq_spec_razr, 20*log10(abs(spec_razr)))
mx = max(20*log10(abs(spec_srcdir)));
ylim( [mx-20, mx+5])
xlim([50, 20e3])
grid on
xlabel('Frequency /Hz')
ylabel('|FRF| /dB(FS)')
title('Reflection Path Source Directivity')
legend({'SOFA DIR', 'RAZR RIR'})
savefig('test_srcdir_semianechoic.reflection.fig')
saveas(gcf(), 'test_srcdir_semianechoic.spectra.reflection.png')

%% Reflection path wall -y ({-z; -y; -x; +x; +y; +z})
room.materials(:, :) = 0.9999;    
room.materials(2, :) = 0.0;

distance = 1/sqrt(2); % direct path distance
room.srcpos = [5, distance/2, 4];
room.srcdir = [0, 0];
room.recpos = [5+distance, distance/2, 4];
room.recdir = [180, 0];
scene(room)

% distance of reflection path shuld be equal 1 now
% just test reflection path distance:
distance_direct_m = norm(room.srcpos-room.recpos);
distance_reflection_m = 2*sqrt((distance_direct_m/2)^2+room.srcpos(2)^2);
assert(abs(distance_reflection_m-1)<1e-5, 'Reflection path distance should be 1.')

ir_dir = razr(room, op);

% index of -45° impulse response
idx = knnsearch(stDir.vertices, [1/sqrt(2), -1/sqrt(2), 0], 'K', 1);
spec_srcdir = fft(stDir.IR(idx, :), [], 2);
spec_srcdir = spec_srcdir(1:end/2+1);
spec_srcdir(2:end-1) = 2 * spec_srcdir(2:end-1);
nfft = size(stDir.IR, 2);
freq_spec_srcdir = stDir.fs * (0:nfft/2) / nfft;

figure()
semilogx(freq_spec_srcdir, 20*log10(abs(spec_srcdir)));
hold on
spec_razr = fft(ir_dir.sig_early(:,1), [], 1);
nfft = size(ir_dir.sig_direct, 1);
spec_razr = spec_razr(1:round(nfft/2+1));
spec_razr(2:end-1) = 2 * spec_razr(2:end-1);
freq_spec_razr = ir_dir.fs * (0:round(nfft/2)) / nfft;
semilogx(freq_spec_razr, 20*log10(abs(spec_razr)))
mx = max(20*log10(abs(spec_srcdir)));
ylim( [mx-20, mx+5])
xlim([50, 20e3])
grid on
xlabel('Frequency /Hz')
ylabel('|FRF| /dB(FS)')
title('Reflection Path Source Directivity')
legend({'SOFA DIR', 'RAZR RIR'})
savefig('test_srcdir_semianechoic.reflection_y.fig')
saveas(gcf(), 'test_srcdir_semianechoic.spectra.reflection_y.png')
