function dbase = hrtf_params_sofa(dbase, cfg)
% HRTF_PARAMS_SOFA

%------------------------------------------------------------------------------
% RAZR engine for Mathwork's MATLAB
%
% Version 0.96.3
%
% Author(s): Torben Wendt
%
% Copyright (c) 2014-2023, Torben Wendt, Steven van de Par, Stephan Ewert,
% University of Oldenburg, Germany.
%
% This work is licensed under the
% Creative Commons Attribution-NonCommercial-NoDerivs 4.0 International
% License (CC BY-NC-ND 4.0).
% To view a copy of this license, visit
% http://creativecommons.org/licenses/by-nc-nd/4.0/ or send a letter to
% Creative Commons, 444 Castro Street, Suite 900, Mountain View, California,
% 94041, USA.
%------------------------------------------------------------------------------


%% Paths and filenames

if isfield(cfg, 'sofa_api_path')
    oldpath = addpath(cfg.sofa_api_path);
else
    error('Path to SOFA API not specified in razr.cfg.m.');
end

% SE old code
if (0)
SOFAstart('silent');
dbase.sofaobj = SOFAload(dbase.sofa_filename);

path(oldpath);
dbase.did_addpath = false;

dbase.len = size(dbase.sofaobj.Data.IR, 3);
dbase.fs = dbase.sofaobj.Data.SamplingRate;

return
end

% SE new code for SOFA HRIR interpolation
try
    % CK 2022-12: there appears to be a problem that you can start sofa only once,
    % afterwards, the "SOFAstart"-command is not available anymore.
    % hence, it depends on whether we use sofa-source directivity also,
    % who gets called first. I have quick-and-dirty fixed this with the
    % "try" routine in both cases. If sofa API is not found, things will
    % fail anyways...
    SOFAstart('silent');
end

%% CK 2022-12: if we want to do interpolation, we need additional hull
% adapted from SG's source directivity

save_convex_hull = 1;

stSofa = SOFAload(dbase.sofa_filename);

stDirDb = new_dirstruct();
stDirDb.fpath_sofa = dbase.sofa_filename;
stDirDb.azim = stSofa.SourcePosition(:, 1);
stDirDb.elev = stSofa.SourcePosition(:, 2);
stDirDb = retrieve_convex_hull(stDirDb, save_convex_hull);
stDirDb.IR = squeeze(stSofa.Data.IR); % second dimension is channel samples x channels x directions
stDirDb.fs = stSofa.Data.SamplingRate;
stDirDb.IRdelay = stSofa.Data.Delay;

stDirDb.GLOBAL_SOFAConventions = stSofa.GLOBAL_SOFAConventions;

dbase.sofaobj = stDirDb;

path(oldpath);
dbase.did_addpath = false;

dbase.len = size(dbase.sofaobj.IR, 3);
dbase.fs = dbase.sofaobj.fs;

end

% dublicated subfcns from load_source_directivity_sofa

function stDir = retrieve_convex_hull(stDir, save_hull)
    % Returns stDir with additional fields of convex hull.
    stDir.fpath_convex_hull = strcat(stDir.fpath_sofa, '.chull.mat');
    fchull = dir(stDir.fpath_convex_hull);
    fsofa = dir(stDir.fpath_sofa);
    if ~isempty(fchull)
        chull_is_newer_than_sofa = fchull.datenum > fsofa.datenum;
    else
        chull_is_newer_than_sofa = false;
    end
    if isfile(stDir.fpath_convex_hull) && chull_is_newer_than_sofa
        stDir = load_convex_hull_data(stDir);
    else
        stDir = create_convex_hull(stDir);
        if save_hull
            save_convex_hull_data(stDir);
        end
    end
end

function stDir = load_convex_hull_data(stDir)
    stHull = load(stDir.fpath_convex_hull);
    stDir.convex_hull = stHull.convex_hull;
    stDir.vertices = stHull.vertices;
    stDir.centroids = stHull.centroids;
    stDir.centroids_azim = stHull.centroids_azim;
    stDir.centroids_elev = stHull.centroids_elev;
end

function save_convex_hull_data(stDir)
    stHull.fpath_sofa = stDir.fpath_sofa;
    stHull.convex_hull = stDir.convex_hull;
    stHull.vertices = stDir.vertices;
    stHull.centroids = stDir.centroids;
    stHull.centroids_azim = stDir.centroids_azim;
    stHull.centroids_elev = stDir.centroids_elev;
    save(stDir.fpath_convex_hull, '-struct', 'stHull')
end

%% end CK, SE
