function [b,a] = highShelvingMatched(fc,gain,fs)

% 1st order high-shelving filter with predescribed nyquist frequency gain
% https://vicanek.de/articles/ShelvingFits.pdf Martin Vicanek
% Matched One-Pole Digital Shelving Filters, 2019

% SE 25.01.2021

%Phi = 1-cos(pi*fc*2/fs);
G = 10^(gain/20);
fc = fc*2/fs;

% SE added f = 0 handling
if fc <= 0
    b = [G -G];
    a = [1 -1];
    return;
end

% matching frequency (match to analog design)
fm = 0.9; % nyquist is 1
Phim = 1-cos(pi*fm);

alpha = 2/pi^2*(1/fm^2+1/(G*fc^2))-1/Phim;
beta = 2/pi^2*(1/fm^2+G/(fc^2))-1/Phim;

a1 = -alpha/(1+alpha+sqrt(1+2*alpha));
b = -beta/(1+beta+sqrt(1+2*beta));
b0 = (1+alpha)/(1+b);
b1 = b*b0;

a = [1 a1];
b = [b0 b1];

% SE added DC gain normalization
% DC gain 
DCg = sum(b)/sum(a);

b = b/DCg;

