% 1st order high-pass filter with predescribed nyquist frequency gain
% works for fc -> inf
% SE 2021, 2022

function [b,a] = hpMatched(fc,fs)



% % approximate analog HP with also cutoffs above fs/2 using the matched
% % shelving filter design
% f2 = fc/100250; % empirically fitted to match correctly for 100 Hz cutoff and 200 dB gain in shelving filter
% % use shelving filter as HP with 200 dB gain re DC
% [b,a] = highShelvingMatched(f2,200,fs);
% b=b*10^(-200/20); % remove gain again to reach unity at f->inf
% 
% % remove the lowf shelving part
% bcut = a;
% bcut = bcut*10^(-200/20);
% b= (b - bcut)/(1-10^(-200/20));


g = 1e5; % use 100 dB gain, i.e. we can keep the 6 dB/oct slope for 100/6 = 16 octaves or 5 decades
g2 = 1;
fuse = fc;
ffactor = 2;
if fc > ffactor*fs
    g2 = (ffactor*fs)/fc; % just change the overall gain once we are past that frequency
    fuse = ffactor*fs;
end
[b,a] = highShelvingMatchedModified(fuse,g,fs);
b=b*g2;

% %same as
% [b,a] = highShelvingMatched(fuse/sqrt(g),20*log10(g),fs);
% b=b/g*g2;

% % convert to LP
% b1 = a;
% b = b1-b;
% 
% 

% debug plot
% % HP
% [b2,a2] = butter(1,min(fc,fs/2.0001)*2/fs,'high');
% 

% pulse =[1; zeros(fs-1,1)];
% out = filter(b,a,pulse);
% % out2 = filter(b2,a2,pulse);
% % out3 = filter(b3,a3,pulse);
% 
% figure(1)
% % analog reference
% s = i*[0:fs-1]'/fc;
% %semilogx(20*log10(abs(1./(1+s))),'k:')
% semilogx(20*log10(abs(s./(1+s))),'k:')
% hold on
% 
% %semilogx(20*log10(abs(fft(out2))))
% %semilogx(20*log10(abs(fft(out3))))
% hold on
% semilogx(20*log10(abs(fft(out))))
% %semilogx(20*log10(abs(fft(out3))))
% xlim([10 20000])
% %ylim([-40 5])
% 
% % error
% figure(2)
% semilogx(20*log10(abs(fft(out)))-20*log10(abs(s./(1+s))))
% hold on
% xlim([10 20000])


function [b,a] = highShelvingMatchedModified(fc,gain,fs)

% 1st order high-shelving filter with predescribed nyquist frequency gain
% https://vicanek.de/articles/ShelvingFits.pdf Martin Vicanek
% Matched One-Pole Digital Shelving Filters, 2019

% SE 25.01.2021

% SE 2022, changed to linear gain, adapted to produce HP design with gain
% range

%Phi = 1-cos(pi*fc*2/fs);
G = gain;
fc = fc*2/fs;

% SE added f = 0 handling
if fc <= 0
    b = [G -G];
    a = [1 -1];
    return;
end

% matching frequency (match to analog design)
fm = 0.9; % nyquist is 1
Phim = 1-cos(pi*fm);

alpha = 2/pi^2*(1/fm^2+1/(1*fc^2))-1/Phim;
beta = 2/pi^2*(1/fm^2+G^2/(fc^2))-1/Phim;

a1 = -alpha/(1+alpha+sqrt(1+2*alpha));
b = -beta/(1+beta+sqrt(1+2*beta));
b0 = (1+alpha)/((1+b));
b1 = b*b0;

a = [1 a1];
b = [b0 b1];

% SE added DC gain normalization
% DC gain 
DCg = sum(b)/sum(a);

b = b/DCg/G; % remove gain so that we reach 0 dB gain at f = inf
