% Given segment pq and triangle abc, returns whether segment intersects
% triangle and if so, also returns the barycentric coordinates (u,v,w)
% of the intersection point 

% Stephan Ewert 2021
% apadted MT97 which can use precomputed normal adapted from Ericson, C. (2004). Real-time collision detection, CRC Press.

% this is 10 times faster than TriangleRayIntersection

function [intersect, t, u, v] = intersectRayTriangle(p, dir, a, b, c, geoeps) 
%float &u, float &v, float &w, float &t)


intersect = 0;
t = NaN;
u = NaN;
v = NaN;
%w = NaN;


ab = b-a; % edge 1
ac = c-a; % edge 2
%qp = -dir; 

% Compute triangle normal. Can be precalculated or cached if
% intersecting multiple segments against the same triangleVector 

% we can use the precomputed normal, but it has to be not normalized, just
% speed ups by 4%
%n = cross(ab, ac);

% this is x times faster than cross
n = [ab(2)*ac(3)-ab(3)*ac(2); ab(3)*ac(1)-ab(1)*ac(3); ab(1)*ac(2)-ab(2)*ac(1)]; 

% Compute denominator d. If d < 0 we hit from backside, if d > 0 from front if 0 ray is parallel to 
%triangle, so exit early

%d = dot(-dir, n);
%n = n';
d = -dir*n;

geoeps = abs(d)*geoeps; % compatibility to old triangle intersection

% split in three parts, so we can postpone the division by d to the end and
% use <> 0 tests depending on sign of d
if d > geoeps
    
    % Compute intersection t value of pq with plane of triangle. A ray
    % intersects iff 0 <= t. Segment intersects if 0 <= t <= 1. Delay
    % dividing by d until intersection has been found to pierce triangle
    
    ap = p-a;
    %t = dot(ap, n);
    t = ap*n;
    
    if t < 0
        return;
    end
    
    % if t > d
    %     return; % For segment; exclude this code line for a ray test
    % end
    
    % Compute barycentric coordinate components and test if within bounds
    
%     e = cross(-dir, ap);
%     e = e';
    
    e = [-dir(2)*ap(3)+dir(3)*ap(2); -dir(3)*ap(1)+dir(1)*ap(3); -dir(1)*ap(2)+dir(2)*ap(1)]; 
   % u = dot(ac, e);
    u = ac*e;
    
    if u < -geoeps || u > d+geoeps
        return;
    end
    
    %v = -dot(ab, e);
    v = -ab*e;
    
    if v < -geoeps || u + v > d+geoeps
        return;
    end
    
elseif d < -geoeps
    
    % invert all 0 tests
    
    ap = p-a;
    %t = dot(ap, n);
    t = ap*n;
    
    if t > 0
        return;
    end
    
    % if t > d
    %     return; % For segment; exclude this code line for a ray test
    % end
    
    % Compute barycentric coordinate components and test if within bounds
    
%     e = cross(-dir, ap);
%     e = e';
    
      e = [-dir(2)*ap(3)+dir(3)*ap(2); -dir(3)*ap(1)+dir(1)*ap(3); -dir(1)*ap(2)+dir(2)*ap(1)]; 
    %u = dot(ac, e);
    u = ac*e;
    
    if u > geoeps || u < d-geoeps
        return;
    end
    
    %v = -dot(ab, e);
    v = -ab*e;
    
    if v > geoeps  || u + v < d-geoeps
        return;
    end
else
    return;
end

% Segment/ray intersects triangle. Perform delayed division and 
% compute the last barycentric coordinate component
ood = 1/d;
t = t*ood;
u = u*ood;
v = v*ood;
%w = 1-u-v;

intersect = 1;
