% 1st order low-pass filter with predescribed nyquist frequency gain
% based on impulse response invariant design and an additional zero at fs/2
% to compensate for aliasing. Considerably smaller error than bilinear
% design.
%
% works for fc = inf
% accepts fs = 0, however runs into numerical issues for fc < fs/1000000, like butter, too.
%
% SE 2022

function [b,a] = lpMatched(fc,fs)

% SE based on my IRIfolp
[b, a]=IRIfolp(fc,fs);

% calculate aliased gain at nyquist*nyfac
nyfac = 0.9;
anygain = (abs(b(1)/(a(1) + a(2)*exp(-i*pi*nyfac))));

% calculate desired gain at nyquist
nygain = (abs(1/(1 + i*fs/2*nyfac/fc)));

% remove difference gain at nyquist
cutgain = nygain/anygain;
bc = [0.5+cutgain/2 0.5-cutgain/2]; % compensate cutgain @ nyquist
% bc = [1 0]
b = b * bc;
 
% % % transform this to hp
% % b = a - b;
% 
% 
% % debug plot
% % [b2,a2]=butter(1,fc*2/fs); % bilinear design
% 
% pulse =[1; zeros(fs-1,1)];
% out = filter(b,a,pulse);
% % out2 = filter(b2,a2,pulse);
% 
% 
% figure()
% % analog reference
% s = i*[0:fs-1]/fc;
% semilogx(20*log10(abs(1./(1+s))),'k:') 
% hold on
% % analog ref for highpass
% %semilogx(20*log10(abs(s./(1+s))),'k:')
% 
% semilogx(20*log10(abs(fft(out))))
% % semilogx(20*log10(abs(fft(out2))))
% 
% xlim([10 20000])
%ylim([-40 5])


function [b,a] = IRIfolp(f0,fs)

% SE my good old IRI design script

a = exp(-(2*pi*f0)/fs);
b = 1 - a;
a = [1, -a];
