function [anglesOut] = transformAngles(anglesIn,anglesBase,fromTo,type)

% type: 
% 1 is [azim, elev] (depreciated for campatibility)
% otherwise euler [yaw, pitch, roll] NOT IMPLEMENTED
%
% fromTo
% 0 transform from world coords to anglesBase 
% otherwise transform from anglesBase to world coords
%
% all angles in degrees
%
% SE 2022

if type == 1 
    % get axis/rotm
    % Angles2Axis is the same as MATLABs robotics toolbox eul2rotm(angles/180*pi)
    axis = Angles2AxisSubf( [anglesBase(1) -anglesBase(2) 0] ); % invert elev to pitch, ignore roll if erratically specified in this notation
    
    % direction vector in cart coords
    [vec(:,1) vec(:,2) vec(:,3)]  = sph2cart(anglesIn(:,1)/180*pi, anglesIn(:,2)/180*pi, anglesIn(:,1)*0+1);
    
    % project into new base
    if fromTo == 0 % from world coords to anglesBase
        vecOut = axis'*vec';
    else
        vecOut = axis*vec'; % from anglesBase to world coords
    end
    
    vecOut = vecOut';
    
    % convert to spherical coords again
    [anglesOut(:,1), anglesOut(:,2), R]  = cart2sph(vecOut(:,1), vecOut(:,2), vecOut(:,3));
    
    % rad to angles
    anglesOut = anglesOut/pi*180;
    
else
    
end


function axis = Angles2AxisSubf( angles )

% axis is a right-handed cart coord system
% first column x (fwd), second column y (left), third column z (up)

% angles are yaw, pitch, roll

% this also constructs a rotation matrix, do we have it already in RAZR?

% should we use degree or rad? MATLAB convention is rad

% this performs euler angle rotation first around x (roll), then pitch,
% then yaw
% Matrix equals rotation matrix R_z(yaw)_y(pitch)_x(roll)

% SE qauke order, I like yaw (z), pitch(y), roll(x) more
% #define PITCH		0
% #define YAW			1
% #define ROLL		2

% same as MATLABs robotics toolbox eul2rotm(angles/180*pi)

    YAW = 1;   % counterclockwise around z (equals azimuth)
    PITCH = 2; % counterclockwise around y (positive is nose down, opposite to elevation)
    ROLL = 3; % counterclockwise around x (forward axis) 
    
    M_PI = pi;
    
    angle = angles(YAW) * (M_PI*2 / 360);
    sy = sin(angle);
    cy = cos(angle);
    angle = angles(PITCH) * (M_PI*2 / 360);
    sp = sin(angle);
    cp = cos(angle);
    angle = angles(ROLL) * (M_PI*2 / 360);
    sr = sin(angle);
    cr = cos(angle);
    
    forward(1) = cp*cy;
    forward(2) = cp*sy;
    forward(3) = -sp;
    
    left(1) = sr*sp*cy+cr*-sy;
    left(2) = sr*sp*sy+cr*cy;
    left(3) = sr*cp;
    
    up(1) = cr*sp*cy+-sr*-sy;
    up(2) = cr*sp*sy+-sr*cy;
    up(3) = cr*cp;
    
    %axis = [forward; left; up];
    axis = [forward' left' up']; % changed to columns
